﻿//+------------------------------------------------------------------+
//|                                             TimeZonesHistory.mq5 |
//|                                    Copyright (c) 2024, marketeer |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property script_show_inputs

// enable detailed output to log via #define before #include
// #define PRINT_DST_DETAILS
#include "TimeServerDST.mqh"

input uint LookupYears = 3;

//+------------------------------------------------------------------+
//| Script program start function                                    |
//+------------------------------------------------------------------+
void OnStart()
{
   if(SymbolInfoString(_Symbol, SYMBOL_CURRENCY_BASE) != "EUR"
   || SymbolInfoString(_Symbol, SYMBOL_CURRENCY_PROFIT) != "USD")
   {
      Alert("It's recommended to apply this script to EURUSD as most liquid Forex instrument");
   }

   PrintFormat("%s ⁞ %s", AccountInfoString(ACCOUNT_COMPANY), AccountInfoString(ACCOUNT_SERVER));
   Print("¹ ⁞ Built-in functions ⁞");
   PRTF(TimeLocal());
   PRTF(TimeCurrent());
   PRTF(TimeTradeServer());
   PRTF(TimeGMT());
   PRTF(TimeGMTOffset());
   PRTF(TimeDaylightSavings());

   Print("² ⁞ Add-on over built-in functions ⁞");
   PRTF(TimeServerGMTOffset());

   Print("³ ⁞ Estimation of server TZ with DST based on week opening hours in history ⁞");
   PRTF(TimeServerDaylightSavings());
   
   ServerTimeZone st[1];
   st[0] = TimeServerZone(LookupYears);
   ArrayPrint(st);
}
//+------------------------------------------------------------------+
/*
  example output without PRINT_DST_DETAILS

  ¹ ⁞ Built-in functions ⁞
  TimeLocal()=2024.10.05 00:39:01 / ok
  TimeCurrent()=2024.10.05 00:38:59 / ok
  TimeTradeServer()=2024.10.05 00:39:01 / ok
  TimeGMT()=2024.10.04 21:39:01 / ok
  TimeGMTOffset()=-10800 / ok
  TimeDaylightSavings()=0 / ok
  ² ⁞ Add-on over built-in functions ⁞
  TimeServerGMTOffset()=-10800 / ok
  ³ ⁞ Estimation of server TZ with DST based on week opening hours in history ⁞
  TimeServerDaylightSavings()=-3600 / ok
      [offsetGMT] [offsetDST] [supportDST]
  [0]      -10800       -3600         true
   
*/
